var User = function(io){
  var Random = require("random-js");
  this._crypto = require('crypto');
  this._random = new Random(Random.engines.mt19937().autoSeed());

  this.salt = this.generateToken(16);

  this.clients = {};

  this.io = io;
};

User.prototype.generateToken = function(length){
  var symbols = ['1','2','3','4','5','6','7','8','9','0','a','b','c','d','e','f','g','h','i','j','k','l','m','n','o','p','q','r','s','t','u','v','w','x','y','z'];
  var token = '';
  for(var i = 0; i < length; i++){
    token = token + symbols[this._random.integer(0, symbols.length-1)];
  }
  return token;
}

User.prototype.sha = function(string){
  return this._crypto.createHash('sha1').update(string).digest("hex");
}

User.prototype.test = function(steamid, token){
  if(this.sha(steamid + ':' + this.salt) == token){
    return true;
  } else {
    return false;
  }
}

User.prototype.newToken = function(steamid){
  return this.sha(steamid + ':' + this.salt);
}

User.prototype.newConnection = function(steamid, socket_id){
  if(!this.clients[steamid]){
    this.clients[steamid] = [];

    this.clients[steamid].push(socket_id);
  } else {
    this.clients[steamid].push(socket_id);
  }
}

User.prototype.emit = function(id, emit, data){
  if(id.length != 17){
    this.io.to(id).emit(emit, data);
  } else {
    if(this.clients[id]){
      if(this.clients[id].length == 0) return;
      for(var i = 0; i < this.clients[id].length; i++){
        this.io.to(this.clients[id][i]).emit(emit, data);
      }
    }
  }
}

User.prototype.disconnect = function(socket_id){
  for(var key in this.clients){
    if(this.clients[key].indexOf(socket_id) > -1){
      this.clients[key].splice(this.clients[key].indexOf(socket_id), 1);

      if(this.clients[key].length == 0) delete this.clients[key];
      break;
    }
  }
}

module.exports = User;
